Demos
=====

.. toctree::
  :maxdepth: 1

  notebooks/demo-compas-analysis
  notebooks/demo-fico-analysis
  notebooks/demo-word-embedding-bias

The demos can also be accessible as Jupyter notebooks
through the `GitHub repository
<https://github.com/ResponsiblyAI/responsibly/tree/master/docs/notebooks>`_.
